@@ -1,5 +1,5 @@
 btest.mean <-
-function(XX,V,theta=1/3,B=1000,pic=1){
+function(XX,V,theta=1/3,B=100,pic=1){
  #XX...sample (list as always)
  #V...expectation we want to test for
  #theta ... is weight in the def of the bertoluzza metric
@@ -25,9 +25,9 @@ function(XX,V,theta=1/3,B=1000,pic=1){
   lower<-min(sample_mean$x[1],V$x[1])
   upper<-max(sample_mean$x[2*nl],V$x[2*nl])
   limx<-c(min(lower)-0.25,max(upper)+0.25)
-  plot(sample_mean,type="l", xlim=limx,lwd=2,xlab=NA, ylab=expression(alpha),cex.main=1, lty="dashed",
-           main=paste("Sample mean (dashed line) and V (solid line)",sep=""))
-  lines(V,type="l", lwd=2,lty="solid")  
+  plot(sample_mean,type="l", xlim=limx,lwd=3,xlab=NA, ylab=expression(alpha),cex.main=1, col="black",
+           main=paste("Sample mean (in black) and V (in red)",sep=""))
+  lines(V,type="l", lwd=3,col="red")  
   }
      
   boot_sample<-replicate(B,sample(XX, nobs,replace=TRUE))
@@ -44,9 +44,9 @@ function(XX,V,theta=1/3,B=1000,pic=1){
    limx<-c(min(c(boot_test_statistic,test_statistic)),max(c(boot_test_statistic,test_statistic)))
    plot(ecdf(boot_test_statistic),xlab=NA,ylab=NA,xlim=limx, do.points = FALSE, main=paste("Ecdf of T*"),cex.main=1,lwd=1.5)
     #cex.axis=1.3,cex.lab=1.3)
-   abline(a = NULL, b = NULL, v = test_statistic,col="black",lty="dotted",lwd=3)
+   abline(a = NULL, b = NULL, v = test_statistic,col="red")
    TS<-test_statistic
-   mtext(paste("T=",round(TS,2),sep=""), at = TS,  side = 1, line = 2, col = "black", bg="white",cex=1.3)
+   mtext(paste("T=",round(TS,2),sep=""), at = TS,  side = 1, line = 2, col = "red", bg="white",cex=1.3)
    }
   pvalue<-mean(test_statistic<boot_test_statistic)
   invisible(pvalue)
